# Tomo Documentation

Welcome to the Tomo documentation! This guide will help you integrate Tomo's Python-based tool orchestration framework with TypeScript, Next.js, and the Vercel AI SDK.

## 📚 Documentation Structure

### Getting Started
- **[TypeScript Integration Overview](./typescript-integration.md)** - High-level overview of integration options
- **[Setup Guide](./setup.md)** - Step-by-step installation and configuration
- **[Quick Start](./quickstart.md)** - Get up and running in 5 minutes

### Integration Guides
- **[Next.js Integration](./nextjs-integration.md)** - Complete Next.js app integration
- **[Vercel AI SDK Integration](./vercel-ai-sdk.md)** - Using Tomo tools with Vercel AI SDK
- **[MCP Protocol](./mcp-protocol.md)** - Model Context Protocol integration details

### Examples
- **[Basic Examples](./examples/basic.md)** - Python tools + TypeScript integration examples
- **[Advanced Examples](./examples/advanced.md)** - Complex orchestration patterns
- **[Full Applications](./examples/applications.md)** - Complete application examples
- **[Complete Code Examples](./examples/code/)** - Ready-to-run Python and TypeScript code

### Reference
- **[API Reference](./api-reference.md)** - TypeScript client API documentation
- **[Configuration](./configuration.md)** - Configuration options and environment setup
- **[Troubleshooting](./troubleshooting.md)** - Common issues and solutions

## 🚀 Quick Links

| Integration Type | Documentation | Example |
|------------------|---------------|---------|
| **REST API** | [Setup Guide](./setup.md#rest-api-integration) | [Basic Example](./examples/basic.md#rest-api) |
| **MCP Protocol** | [MCP Guide](./mcp-protocol.md) | [MCP Example](./examples/basic.md#mcp-integration) |
| **Next.js App** | [Next.js Guide](./nextjs-integration.md) | [Full App](./examples/applications.md#nextjs-chat-app) |
| **Vercel AI SDK** | [AI SDK Guide](./vercel-ai-sdk.md) | [AI Chat](./examples/applications.md#ai-chat-with-tools) |

## 🎯 Choose Your Integration

### For Simple Tool Execution
**Use REST API integration** if you need basic tool execution without real-time features.
→ [REST API Setup](./setup.md#rest-api-integration)

### For AI Agent Applications
**Use MCP integration** if you're building AI applications that need dynamic tool discovery.
→ [MCP Setup](./setup.md#mcp-integration)

### For Production Applications
**Use Next.js with Vercel AI SDK** for production-ready applications with streaming and real-time features.
→ [Production Setup](./nextjs-integration.md)

## 📋 Prerequisites

- **Node.js 18+** and **npm/yarn/pnpm**
- **Python 3.10+** with Tomo installed
- **Basic knowledge** of TypeScript and React/Next.js
- **Optional**: Vercel AI SDK familiarity

## 🤝 Community

- **GitHub Issues**: [Report bugs or request features](https://github.com/tomo-framework/tomo/issues)
- **Discussions**: [Ask questions and share ideas](https://github.com/tomo-framework/tomo/discussions)
- **Examples**: [Community examples and templates](https://github.com/tomo-framework/tomo/tree/main/examples)

## 📝 Contributing

Found an issue with the documentation? Want to add examples?
[Contribute to the docs](../CONTRIBUTING.md) - we welcome improvements!

---

**Next**: Start with the [TypeScript Integration Overview](./typescript-integration.md) to understand your options. 